<?php

namespace Shirtworks\Qute\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Shirtworks\Qute\Http\Requests\QutesRequest;
use Shirtworks\Qute\Models\Qutes;

/**
 * Admin web controller class.
 */
class QutesWorkflowController extends BaseController
{

    /**
     * Workflow controller function for qutes.
     *
     * @param Model   $qutes
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(QutesRequest $request, Qutes $qutes, $step)
    {

        try {

            $qutes->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('qute::qutes.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/qutes/qutes/' . $qutes->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/qutes/qutes/' . $qutes->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for qutes.
     *
     * @param Model   $qutes
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Qutes $qutes, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $qutes->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('qute::qutes.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('qute::admin.qutes.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('qute::admin.qutes.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('qute::admin.qutes.message', $data)->render();

        }

    }
}
