<?php

namespace Shirtworks\Qute\Providers;

use Illuminate\Support\ServiceProvider;

class QuteServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'qute');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'qute');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('shirtworks.qute', function ($app) {
            return $this->app->make('Shirtworks\Qute\Qute');
        });

                // Bind Qutes to repository
        $this->app->bind(
            'Shirtworks\Qute\Interfaces\QutesRepositoryInterface',
            \Shirtworks\Qute\Repositories\Eloquent\QutesRepository::class
        );

        $this->app->register(\Shirtworks\Qute\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Shirtworks\Qute\Providers\RouteServiceProvider::class);
                $this->app->register(\Shirtworks\Qute\Providers\WorkflowServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['shirtworks.qute'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('shirtworks/qute.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/qute')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/qute')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
